==> foundation-0.2.24.tgz: package/lib/esm/components/antRow.js <==
import { __rest } from "tslib";
import React from 'react';
import { forwardRef } from 'coral-system';
import { Row, Col } from 'antd';
//import { Placeholder } from '../../../antd/src/components/placeholder';
import { Placeholder } from '@music163/antd';
// const Row = coral('div', undefined, {
//   prefix: '--music',
// });
export const AntRow = forwardRef((_a, ref) => {
    var { isRender = true } = _a, props = __rest(_a, ["isRender"]);
    if (isRender === false)
        return React.createElement(React.Fragment, null);
    console.log('zcqtestGrid', props);
    const _b = props, { gridConfig } = _b, restProps = __rest(_b, ["gridConfig"]);
    if (gridConfig !== undefined && gridConfig.length > 0) {
        const rows = gridConfig.length;
        console.log('zcq一共几行', rows);
        let gridArray = [];
        gridConfig.forEach((rowItem, rowIndex) => {
            //处理每行
            const rowConfig = rowItem.rowConfig;
            const { gutter, verticalGap = "" } = rowConfig;
            //一次生成一行
            //处理每列
            const colConfig = rowItem.colConfig;
            const cols = colConfig.length;
            console.log('第' + rowIndex + '行一共几列', cols);
            let colsArray = [];
            colConfig.forEach((colItem, colIndex) => {
                console.log('第' + rowIndex + '行第' + colIndex + '列', colItem);
                const { span } = colItem, restColProps = __rest(colItem, ["span"]);
                colsArray = Array.from({ length: cols }, (_, index) => (React.createElement(Col, { span: span },
                    React.createElement(Placeholder, null))));
            });
            console.log('colsArray', colsArray);
            gridArray.push((React.createElement(Row, Object.assign({ key: rowIndex, ref: ref, gutter: gutter }, props, { style: { marginBottom: "" + verticalGap + "" } }), colsArray)));
        });
        const rowsArray = Array.from({ length: 1 }, (_, index) => (React.createElement("div", null,
            React.createElement(Row, Object.assign({ key: index, ref: ref, gutter: [20, 10] }, props, { style: { marginBottom: '20px' } }),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null)),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null)),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null))),
            React.createElement(Row, Object.assign({ key: index, ref: ref, gutter: [20, 10] }, props),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null)),
                React.createElement(Col, { span: 16 },
                    React.createElement(Placeholder, null))))));
        console.log('最终生成的01', rowsArray);
        console.log('最终生成的02', gridArray);
        return (React.createElement("div", null, gridArray));
    }
});
const convertMapToObject = (map) => {
    const result = {};
    for (const [key, value] of map) {
        result[key] = value;
    }
    return result;
};

==> foundation-0.2.25.tgz: package/lib/esm/components/antRow.js <==
import { __rest } from "tslib";
import React from 'react';
import { forwardRef } from 'coral-system';
import { Row, Col } from 'antd';
//import { Placeholder } from '../../../antd/src/components/placeholder';
import { Placeholder } from '@cuvp1225/antd';
// const Row = coral('div', undefined, {
//   prefix: '--music',
// });
export const AntRow = forwardRef((_a, ref) => {
    var { isRender = true } = _a, props = __rest(_a, ["isRender"]);
    if (isRender === false)
        return React.createElement(React.Fragment, null);
    console.log('zcqtestGrid', props);
    const _b = props, { gridConfig } = _b, restProps = __rest(_b, ["gridConfig"]);
    if (gridConfig !== undefined && gridConfig.length > 0) {
        const rows = gridConfig.length;
        console.log('zcq一共几行', rows);
        let gridArray = [];
        gridConfig.forEach((rowItem, rowIndex) => {
            //处理每行
            const rowConfig = rowItem.rowConfig;
            const { gutter, verticalGap = "" } = rowConfig;
            //一次生成一行
            //处理每列
            const colConfig = rowItem.colConfig;
            const cols = colConfig.length;
            console.log('第' + rowIndex + '行一共几列', cols);
            let colsArray = [];
            colConfig.forEach((colItem, colIndex) => {
                console.log('第' + rowIndex + '行第' + colIndex + '列', colItem);
                const { span } = colItem, restColProps = __rest(colItem, ["span"]);
                colsArray = Array.from({ length: cols }, (_, index) => (React.createElement(Col, { span: span },
                    React.createElement(Placeholder, null))));
            });
            console.log('colsArray', colsArray);
            gridArray.push((React.createElement(Row, Object.assign({ key: rowIndex, ref: ref, gutter: gutter }, props, { style: { marginBottom: "" + verticalGap + "" } }), colsArray)));
        });
        const rowsArray = Array.from({ length: 1 }, (_, index) => (React.createElement("div", null,
            React.createElement(Row, Object.assign({ key: index, ref: ref, gutter: [20, 10] }, props, { style: { marginBottom: '20px' } }),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null)),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null)),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null))),
            React.createElement(Row, Object.assign({ key: index, ref: ref, gutter: [20, 10] }, props),
                React.createElement(Col, { span: 8 },
                    React.createElement(Placeholder, null)),
                React.createElement(Col, { span: 16 },
                    React.createElement(Placeholder, null))))));
        console.log('最终生成的01', rowsArray);
        console.log('最终生成的02', gridArray);
        return (React.createElement("div", null, gridArray));
    }
});
const convertMapToObject = (map) => {
    const result = {};
    for (const [key, value] of map) {
        result[key] = value;
    }
    return result;
};
